==> openflowplugin-extension-nicira-0.12.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/SrcChoiceGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import java.lang.Class;
import java.lang.Override;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.SrcChoice;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping src-choice-grouping {
 *   choice src-choice {
 *     case src-nx-reg-case {
 *       uses nxm-nx-reg-grouping;
 *     }
 *     case src-nx-tun-id-case {
 *       uses nxm-nx-tun-id-grouping;
 *     }
 *     case src-nx-of-mpls-label-case {
 *       uses oxm-of-mpls-label-grouping;
 *     }
 *     case src-nx-of-metadata-case {
 *       uses oxm-of-metadata-grouping;
 *     }
 *     case src-nx-arp-sha-case {
 *       uses nxm-nx-arp-sha-grouping;
 *     }
 *     case src-nx-arp-tha-case {
 *       uses nxm-nx-arp-tha-grouping;
 *     }
 *     case src-of-arp-op-case {
 *       uses nxm-of-arp-op-grouping;
 *     }
 *     case src-of-arp-spa-case {
 *       uses nxm-of-arp-spa-grouping;
 *     }
 *     case src-of-arp-tpa-case {
 *       uses nxm-of-arp-tpa-grouping;
 *     }
 *     case src-nx-of-in-port-case {
 *       uses nxm-of-in-port-grouping;
 *     }
 *     case src-nx-tun-ipv4-dst-case {
 *       uses nxm-nx-tun-ipv4-dst-grouping;
 *     }
 *     case src-nx-tun-ipv4-src-case {
 *       uses nxm-nx-tun-ipv4-src-grouping;
 *     }
 *     case src-of-eth-src-case {
 *       uses nxm-of-eth-src-grouping;
 *     }
 *     case src-of-eth-dst-case {
 *       uses nxm-of-eth-dst-grouping;
 *     }
 *     case src-of-eth-type-case {
 *       uses nxm-of-eth-type-grouping;
 *     }
 *     case src-nx-nsp-case {
 *       uses nxm-nx-nsp-grouping;
 *     }
 *     case src-nx-nsi-case {
 *       uses nxm-nx-nsi-grouping;
 *     }
 *     case src-nx-nshc-1-case {
 *       uses nxm-nx-nshc-1-grouping;
 *     }
 *     case src-nx-nshc-2-case {
 *       uses nxm-nx-nshc-2-grouping;
 *     }
 *     case src-nx-nshc-3-case {
 *       uses nxm-nx-nshc-3-grouping;
 *     }
 *     case src-nx-nshc-4-case {
 *       uses nxm-nx-nshc-4-grouping;
 *     }
 *     case src-of-ip-src-case {
 *       uses nxm-of-ip-src-grouping;
 *     }
 *     case src-of-ip-dst-case {
 *       uses nxm-of-ip-dst-grouping;
 *     }
 *     case src-nx-ipv6-src-case {
 *       uses nxm-nx-ipv6-src-grouping;
 *     }
 *     case src-nx-ipv6-dst-case {
 *       uses nxm-nx-ipv6-dst-grouping;
 *     }
 *     case src-nx-nsh-flags-case {
 *       uses nxm-nx-nsh-flags-grouping;
 *     }
 *     case src-nx-nsh-mdtype-case {
 *       uses nxm-nx-nsh-mdtype-grouping;
 *     }
 *     case src-nx-nsh-np-case {
 *       uses nxm-nx-nsh-np-grouping;
 *     }
 *     case src-nx-nsh-ttl-case {
 *       uses nxm-nx-nsh-ttl-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/src-choice-grouping</i>
 *
 */
@Generated("mdsal-binding-generator")
public interface SrcChoiceGrouping
    extends
    DataObject
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("src-choice-grouping");

    @Override
    Class<? extends SrcChoiceGrouping> implementedInterface();
    
    /**
     * Return srcChoice, or {@code null} if it is not present.
     *
     * @return {@code org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.SrcChoice} srcChoice, or {@code null} if it is not present.
     *
     */
    SrcChoice getSrcChoice();

}

==> openflowplugin-extension-nicira-0.13.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/SrcChoiceGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import java.lang.Class;
import java.lang.Override;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.SrcChoice;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping src-choice-grouping {
 *   choice src-choice {
 *     case src-nx-reg-case {
 *       uses nxm-nx-reg-grouping;
 *     }
 *     case src-nx-tun-id-case {
 *       uses nxm-nx-tun-id-grouping;
 *     }
 *     case src-nx-of-mpls-label-case {
 *       uses oxm-of-mpls-label-grouping;
 *     }
 *     case src-nx-of-metadata-case {
 *       uses oxm-of-metadata-grouping;
 *     }
 *     case src-nx-arp-sha-case {
 *       uses nxm-nx-arp-sha-grouping;
 *     }
 *     case src-nx-arp-tha-case {
 *       uses nxm-nx-arp-tha-grouping;
 *     }
 *     case src-of-arp-op-case {
 *       uses nxm-of-arp-op-grouping;
 *     }
 *     case src-of-arp-spa-case {
 *       uses nxm-of-arp-spa-grouping;
 *     }
 *     case src-of-arp-tpa-case {
 *       uses nxm-of-arp-tpa-grouping;
 *     }
 *     case src-nx-of-in-port-case {
 *       uses nxm-of-in-port-grouping;
 *     }
 *     case src-nx-tun-ipv4-dst-case {
 *       uses nxm-nx-tun-ipv4-dst-grouping;
 *     }
 *     case src-nx-tun-ipv4-src-case {
 *       uses nxm-nx-tun-ipv4-src-grouping;
 *     }
 *     case src-of-eth-src-case {
 *       uses nxm-of-eth-src-grouping;
 *     }
 *     case src-of-eth-dst-case {
 *       uses nxm-of-eth-dst-grouping;
 *     }
 *     case src-of-eth-type-case {
 *       uses nxm-of-eth-type-grouping;
 *     }
 *     case src-nx-nsp-case {
 *       uses nxm-nx-nsp-grouping;
 *     }
 *     case src-nx-nsi-case {
 *       uses nxm-nx-nsi-grouping;
 *     }
 *     case src-nx-nshc-1-case {
 *       uses nxm-nx-nshc-1-grouping;
 *     }
 *     case src-nx-nshc-2-case {
 *       uses nxm-nx-nshc-2-grouping;
 *     }
 *     case src-nx-nshc-3-case {
 *       uses nxm-nx-nshc-3-grouping;
 *     }
 *     case src-nx-nshc-4-case {
 *       uses nxm-nx-nshc-4-grouping;
 *     }
 *     case src-of-ip-src-case {
 *       uses nxm-of-ip-src-grouping;
 *     }
 *     case src-of-ip-dst-case {
 *       uses nxm-of-ip-dst-grouping;
 *     }
 *     case src-nx-ipv6-src-case {
 *       uses nxm-nx-ipv6-src-grouping;
 *     }
 *     case src-nx-ipv6-dst-case {
 *       uses nxm-nx-ipv6-dst-grouping;
 *     }
 *     case src-nx-nsh-flags-case {
 *       uses nxm-nx-nsh-flags-grouping;
 *     }
 *     case src-nx-nsh-mdtype-case {
 *       uses nxm-nx-nsh-mdtype-grouping;
 *     }
 *     case src-nx-nsh-np-case {
 *       uses nxm-nx-nsh-np-grouping;
 *     }
 *     case src-nx-nsh-ttl-case {
 *       uses nxm-nx-nsh-ttl-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-actionsrc-choice-grouping</i>
 *
 */
@Generated("mdsal-binding-generator")
public interface SrcChoiceGrouping
    extends
    DataObject
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("src-choice-grouping");

    @Override
    Class<? extends SrcChoiceGrouping> implementedInterface();
    
    /**
     * Return srcChoice, or {@code null} if it is not present.
     *
     * @return {@code SrcChoice} srcChoice, or {@code null} if it is not present.
     *
     */
    SrcChoice getSrcChoice();

}
